@@ -32,7 +32,6 @@ def st_antd_table(df, *, row_key=None,
         default_expand_all_rows=None,
         batch_actions=None,
         linkable_columns=None,
-        revoke_height_step=0,
         expand_column=None,
         expand_json=False,
         action_width=None,
@@ -77,7 +76,7 @@ def st_antd_table(df, *, row_key=None,
         columns.append(column)
     event = _component_func(data=data, columns=columns, actions=actions or None,
         row_key=row_key, min_height=min_height, tags_columns=tags_columns or None, sorter_columns=sorter_columns or None,
-        linkable_columns=linkable_columns or [], batch_actions=batch_actions or None, revoke_height_step=revoke_height_step,
+        linkable_columns=linkable_columns or [], batch_actions=batch_actions or None,
         searchable_columns=searchable_columns or None, actions_in_row=bool(actions_mapper), iframe_height=iframe_height,
         expand_column=expand_column, default_expand_all_rows=default_expand_all_rows, iframes_in_row=bool(iframes_mapper),
         compact_layout=compact_layout,
@@ -138,7 +137,6 @@ if _DEVELOP_MODE or os.getenv('SHOW_TABLE_DEMO'):
         tags_columns=['tags'],
         fixed_left_columns=['name'],
         linkable_columns=['name'],
-        revoke_height_step=300,
         expand_column="description",
         expand_json=expand_json,
         batch_actions=['Batch Delete', 'Batch Mark'],
